pub struct DimensionValue {
pub dimension_name: Option<String>,
pub etag: Option<String>,
pub id: Option<String>,
pub kind: Option<String>,
pub match_type: Option<String>,
pub value: Option<String>,
}Expand description
Represents a DimensionValue resource.
This type is not used in any activity, and only used as part of another schema.
Fields
dimension_name: Option<String>The name of the dimension.
etag: Option<String>The eTag of this response for caching purposes.
id: Option<String>The ID associated with the value if available.
kind: Option<String>The kind of resource this is, in this case dfareporting#dimensionValue.
match_type: Option<String>Determines how the ‘value’ field is matched when filtering. If not specified, defaults to EXACT. If set to WILDCARD_EXPRESSION, ‘’ is allowed as a placeholder for variable length character sequences, and it can be escaped with a backslash. Note, only paid search dimensions (‘dfa:paidSearch’) allow a matchType other than EXACT.
value: Option<String>The value of the dimension.